@@ -1,15 +1,20 @@
 import logging
 import os
+import sys
 from functools import lru_cache
 from pathlib import Path
 from typing import Dict, Optional
 
 import black
-import toml
 from pylsp import hookimpl
 from pylsp._utils import get_eol_chars
 from pylsp.config.config import Config
 
+if sys.version_info >= (3, 11):
+    import tomllib
+else:
+    import tomli as tomllib
+
 logger = logging.getLogger(__name__)
 
 
@@ -87,6 +92,8 @@ def format_text(*, text, config):
         line_length=config["line_length"],
         is_pyi=config["pyi"],
         string_normalization=not config["skip_string_normalization"],
+        magic_trailing_comma=not config["skip_magic_trailing_comma"],
+        preview=config["preview"],
     )
     try:
         # Black's format_file_contents only works reliably when eols are '\n'. It gives
@@ -131,6 +138,7 @@ def _load_config(filename: str, client_config: Config) -> Dict:
         "fast": False,
         "pyi": filename.endswith(".pyi"),
         "skip_string_normalization": False,
+        "skip_magic_trailing_comma": False,
         "target_version": set(),
         "preview": settings.get("preview", False),
     }
@@ -152,8 +160,9 @@ def _load_config(filename: str, client_config: Config) -> Dict:
             return defaults
 
     try:
-        pyproject_toml = toml.load(str(pyproject_filename))
-    except (toml.TomlDecodeError, OSError):
+        with open(pyproject_filename, "rb") as f:
+            pyproject_toml = tomllib.load(f)
+    except (tomllib.TOMLDecodeError, OSError):
         logger.warning(
             "Error decoding pyproject.toml, using defaults: %r",
             defaults,
